# bnrxrates

Python3 utility for easily accessing and parsing XML documents containing the exchange rates published by BNR (Romanian National Bank / Banca Națională a României) on their website.

## Features

- Fetch XML documents from https://www.bnr.ro with simple function calls.
- Parse XML into a Pythonic format.
- Cache retrieved data.

## Installation


## Usage


## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.